rm(list=ls())
library(ggplot2)
library(rstan)
library(ggmcmc)

#1st step Bayesian model
for(Sel_T in c( 55,60,65,70,74,76,78,80 ) )
{
	#Observed colony count data
	d <- read.csv(file='02_input/Combase_data_set.csv')
	d <- d[d$TE==paste(Sel_T), ]
	d_k <- d[ d$TIME != 0, ]
	Nt <- 10 ^ d_k[ ,2]
	N0 <- 10 ^ 6.57
	time <- d_k[ ,1]
	#k(T) estimated from each observed data
	d_k[ ,2] <- ( 1 / time ) * log10( N0 / Nt )
	data <- list( N = nrow(d_k) , TIME = d_k$TIME , N_T = d_k$N_T , TE = d_k$TE )
	#MCMC_fitting
	fit <- stan( file = '03_model/model_2step_Bayesian.stan' , data = data , seed = 1234 , iter = 5000 , chain = 4 , thin=1)
	save.image( file = paste("04_output/result_model_1step_",Sel_T,".RData",sep="") )
}


#2nd step Bayesian model
rm(list=ls())
Temp <-c( 55,60,65,70,74,76,78,80 )
load(paste("04_output/result_model_1step_",55,".RData",sep=""))
ms <- rstan::extract(fit)
box <- matrix(0,length(ms$lp),length(Temp))

for(Z in 1:8)
{
	load(paste("04_output/result_model_1step_",Temp[Z],".RData",sep=""))
	#MCMC_output
	ms <- rstan::extract(fit)
	box[ ,Z] <- rlnorm(length(log(ms$kT)),log(ms$kT),ms$sigma)
}
kdata <- (box)
kdatal <- log(box)
Tbox <- matrix(rep(Temp,each=length(ms$lp)),length(ms$lp),length(Temp))
#plot(Tbox[,1],kdata[,1],xlim=c(55,80),ylim=c(0,8000))

kdata1c <- c(kdata[,1][floor(runif(100, min=1, max=length(ms$lp)+1))],kdata[,2][floor(runif(100, min=1, max=length(ms$lp)+1))],kdata[,3][floor(runif(100, min=1, max=length(ms$lp)+1))],kdata[,4][floor(runif(100, min=1, max=length(ms$lp)+1))],kdata[,5][floor(runif(100, min=1, max=length(ms$lp)+1))],kdata[,6][floor(runif(100, min=1, max=length(ms$lp)+1))],kdata[,7][floor(runif(100, min=1, max=length(ms$lp)+1))],kdata[,8][floor(runif(100, min=1, max=length(ms$lp)+1))])
Tbox1c <- c(Tbox[,1][1:100],Tbox[,2][1:100],Tbox[,3][1:100],Tbox[,4][1:100],Tbox[,5][1:100],Tbox[,6][1:100],Tbox[,7][1:100],Tbox[,8][1:100])

d <- data.frame(TE=Tbox1c,k=kdata1c)
data <- list( N = nrow(d) , TE = d$TE ,N_T = d$k , TIME=d$k)

fit <- stan( file = '03_model/model_Bayesian.stan' , data = data , seed = 1234 , iter = 5000 , chain = 4 , thin=1)
save.image( file = '04_output/result_model_2step_Bayesian.RData' )
load('04_output/result_model_2step_Bayesian.RData')
#MCMC_output
ms <- rstan::extract(fit)